/*
 * Copyright (c) 田梓萱[小草林] 2021-2024.
 * All Rights Reserved.
 * All codes are protected by China's regulations on the protection of computer software, and infringement must be investigated.
 * 版权所有 (c) 田梓萱[小草林] 2021-2024.
 * 所有代码均受中国《计算机软件保护条例》保护，侵权必究.
 */
package com.caverock.androidsvg;

import com.caverock.androidsvg.utils.CSSBase;

/**
 * This is a container for pre-parsed CSS that can be used to avoid parsing raw CSS string on each
 * render. It can be passed to RenderOptions like this:
 *
 * <pre class="code-block">{@code
 * CSS css = CSS.getFromString("...some complex and long css here that takes time to parse...")
 * RenderOption renderOptions = RenderOptions.create();
 * renderOptions.css(css) // And now you can reuse the already parsed css
 * svg1.renderToCanvas(canvas, renderOptions);
 * svg2.renderToCanvas(canvas, renderOptions);
 * svg3.renderToCanvas(canvas, renderOptions);
 * }</pre>
 */
public class CSS extends CSSBase {
  private CSS(String css) {
    super(css);
  }

  /**
   * @param css css string to parse
   * @return pre-parsed CSS
   */
  public static CSS getFromString(String css) {
    return new CSS(css);
  }
}
